
/* Drop Indexes */

DROP INDEX ActionScheduleData_Index1;
DROP INDEX ActionScheduleData_Index2;
DROP INDEX ActionScheduleData_Index3;
DROP INDEX ConstructionBaseInfo_Index1;
DROP INDEX ConstructionBaseInfo_Index2;
DROP INDEX ConstructionBaseInfo_Index3;
DROP INDEX ConstructionBaseInfo_Index4;
DROP INDEX ConstructionBaseInfo_Index5;
DROP INDEX BaseInfoDetail_Idx1;
DROP INDEX BaseInfoDetail_Idx2;
DROP INDEX LedgerExcute_Index1;
DROP INDEX CostDataOfPerson_Index1;
DROP INDEX CostDataOfPerson_Index2;
DROP INDEX EstimateData_Index1;
DROP INDEX EstimateDataBody_Index1;
DROP INDEX EstimateDataDetail_Index1;
DROP INDEX InputSearchLogData_Index1;
DROP INDEX MessageBoardData_Index1;
DROP INDEX MessageBoardData_Index2;
DROP INDEX MessageBoardTerget_Index1;
DROP INDEX SalesGraphData_Idx1;
DROP INDEX SalesGraphData_idx2;
DROP INDEX VehicleScheduleData_Index1;
DROP INDEX VehicleScheduleData_Index2;
DROP INDEX VehicleScheduleData_Index3;



/* Drop Tables */

DROP TABLE ActionScheduleData CASCADE CONSTRAINTS;
DROP TABLE ConstructionBaseInfo CASCADE CONSTRAINTS;
DROP TABLE ConstructionBaseInfoDetail CASCADE CONSTRAINTS;
DROP TABLE ConstructionBudget CASCADE CONSTRAINTS;
DROP TABLE ConstructionBudgetDetail CASCADE CONSTRAINTS;
DROP TABLE ConstructionLedger CASCADE CONSTRAINTS;
DROP TABLE ConstructionLedgerDetail CASCADE CONSTRAINTS;
DROP TABLE ConstructionLedgerExcute CASCADE CONSTRAINTS;
DROP TABLE ConstructionLink CASCADE CONSTRAINTS;
DROP TABLE ConstructionProgressDate CASCADE CONSTRAINTS;
DROP TABLE CostDataOfPerson CASCADE CONSTRAINTS;
DROP TABLE DailyDataConstruction CASCADE CONSTRAINTS;
DROP TABLE DailyDataDetail CASCADE CONSTRAINTS;
DROP TABLE DailyDataField CASCADE CONSTRAINTS;
DROP TABLE DailyDataMaterials CASCADE CONSTRAINTS;
DROP TABLE DailyDataSubcontractors CASCADE CONSTRAINTS;
DROP TABLE DailyDataVehicles CASCADE CONSTRAINTS;
DROP TABLE EstimateBudget CASCADE CONSTRAINTS;
DROP TABLE EstimateBudgetDetail CASCADE CONSTRAINTS;
DROP TABLE EstimateData CASCADE CONSTRAINTS;
DROP TABLE EstimateDataBody CASCADE CONSTRAINTS;
DROP TABLE EstimateDataDetail CASCADE CONSTRAINTS;
DROP TABLE InputSearchLogData CASCADE CONSTRAINTS;
DROP TABLE MessageBoardData CASCADE CONSTRAINTS;
DROP TABLE MessageBoardTerget CASCADE CONSTRAINTS;
DROP TABLE MessageBrowsingHistory CASCADE CONSTRAINTS;
DROP TABLE OrdersPriceData CASCADE CONSTRAINTS;
DROP TABLE PointingOutComment CASCADE CONSTRAINTS;
DROP TABLE ProceedingsData CASCADE CONSTRAINTS;
DROP TABLE ProceedingsDataAttendee CASCADE CONSTRAINTS;
DROP TABLE ProceedingsDataDetail CASCADE CONSTRAINTS;
DROP TABLE ProcessApproval CASCADE CONSTRAINTS;
DROP TABLE PurchaseOrder CASCADE CONSTRAINTS;
DROP TABLE PurchaseOrderDetail CASCADE CONSTRAINTS;
DROP TABLE SalesGraphData CASCADE CONSTRAINTS;
DROP TABLE SystemExecute CASCADE CONSTRAINTS;
DROP TABLE VehicleScheduleData CASCADE CONSTRAINTS;




/* Create Tables */

-- 担当者行動予定データ
CREATE TABLE ActionScheduleData
(
	-- 対象日
	TargetDate date NOT NULL,
	-- 担当者コード
	PersonCode number(8,0) NOT NULL,
	-- 行動予定
	ActionSchedule nvarchar2(30),
	-- 該当年
	TargetYear number(4,0) NOT NULL,
	-- 該当月
	TargetMonth number(2,0) NOT NULL,
	-- 該当日
	TargetDay number(2,0) NOT NULL,
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (TargetDate, PersonCode)
);


-- 工事基本情報
CREATE TABLE ConstructionBaseInfo
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- 紐付データフラグ
	TyingFlg number(1) NOT NULL,
	-- 工事年度
	ConstructionYear number(4,0) NOT NULL,
	-- 工事期数
	ConstructionPeriod number(4,0) NOT NULL,
	-- 依頼受け日
	RequestedDate date,
	-- 見積提出期限
	EstimatesSubmitDeadline date,
	-- 見積提出日
	EstimatesSubmittedDate date,
	-- 仮受注日
	ProvisionalOrderDate date,
	-- 受注日
	OrderDate date,
	-- 開始予定日
	OrderStartingDate date,
	-- 完了予定日
	OrderCompletionDate date,
	-- 施工準備開始日
	PreparationStartDate date,
	-- 施工開始日
	ConstructionStartingDate date,
	-- 施工完了日
	ConstructionCompletionDate date,
	-- 非受注日
	NonOrderDate date,
	-- 税抜受注決定金額
	OrdersDecisionPrice number(12,2) NOT NULL,
	-- 税込受注決定金額
	OrdersDecisionPriceInTax number(12,2) NOT NULL,
	-- 営業担当者名
	SalesPersonCode number(8,0),
	-- 工事担当者
	ConstructionPersonCode number(8,0) NOT NULL,
	-- 工事副担当者
	ConstrSubPersonCode number(8,0) NOT NULL,
	-- 工事指導員
	ConstructionInstructor number(8,0) NOT NULL,
	-- 工事移管先コード
	TransferConstruction number(8,0) NOT NULL,
	-- 工事移管日
	TransferConstructionDate date,
	-- 発注者区分
	OrderersDivision number(5,0) NOT NULL,
	-- 発注者コード
	OrderersCode number(5,0) NOT NULL,
	-- 見積有効期限
	EstimatesExpirationDate date,
	-- 契約工期開始日
	ConstructionPeriodStart date,
	-- 契約工期完了
	ConstructionPeriodEnd date,
	-- 契約工期開始（延長時）
	ConstructionPeriodStart2 date,
	-- 契約工期完了（延長時）
	ConstructionPeriodEnd2 date,
	-- 工事開始日
	StartDate date,
	-- 工事終了日
	EndDate date,
	-- 注文書郵送日
	PurchaseOrderMailingDate date,
	-- 注文書返送日
	PurchaseOrderReturnDate date,
	-- 注文書返送確認日
	PurchaseOrderReturnCheckDate date,
	-- 消費税フラグ
	ConsumptionTaxFlg number(1) NOT NULL,
	-- 元請フラグ
	PrimeContractorFlg number(1) NOT NULL,
	-- 営業経費発生フラグ
	SalesCostFlg number(1) NOT NULL,
	-- 工事状態フラグ
	ConstructionStatusFlg number(2,0) NOT NULL,
	-- 工事種別コード
	ConstructionType number(5,0) NOT NULL,
	-- 見積種別
	EstimateType number(1) NOT NULL,
	-- 請求準備開始日
	BillingStartDate date NOT NULL,
	-- 請求日
	BillingDate date NOT NULL,
	-- 請求回数フラグ
	BillingSplitFlg number(1) NOT NULL,
	-- 請求書郵送/手渡し日
	BillingSendDate date,
	-- 工事詳細台帳入力完了日付
	LedgerComplateDate date NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode)
);


-- 工事基本情報明細
CREATE TABLE ConstructionBaseInfoDetail
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- 明細番号
	DetailNo number(2,0) NOT NULL,
	-- 明細内容
	DetailString nvarchar2(120),
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode, DetailNo)
);


-- 工事施工予算データ
CREATE TABLE ConstructionBudget
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- 作成者コード
	CreatorCode number(8,0) NOT NULL,
	-- 作成者名
	CreatorName nvarchar2(60),
	-- 作成者給与
	CreatorCosts number(11,3) NOT NULL,
	-- 副担当者コード
	AssistantCode number(8,0) NOT NULL,
	-- 副担当者名
	AssistantName nvarchar2(60),
	-- 副担当者給与
	AssistantCosts number(11,3) NOT NULL,
	-- 工事指導員コード
	InstructorCode number(8,0) NOT NULL,
	-- 工事指導員名
	InstructorName nvarchar2(60),
	-- 工事指導員給与
	InstructorCosts number(11,3) NOT NULL,
	-- 作成日
	CreateDate date NOT NULL,
	-- 工期（単位・月）
	ConstructionTimes number(5,2) NOT NULL,
	-- 契約工期開始
	ConstructionStart date NOT NULL,
	-- 契約工期完了
	ConstructionEnd date NOT NULL,
	-- 指導員稼働月数
	InstructorTimes number(5,2) NOT NULL,
	-- 給与振分区分
	SalaryFlg number(1) NOT NULL,
	-- 振分日数
	SalaryDays number(4,0) NOT NULL,
	-- 副担当者給与振分区分
	A_SalaryFlg number(1) NOT NULL,
	-- 副担当者振分日数
	A_SalaryDays number(4,0) NOT NULL,
	-- 指導員給与振分区分
	I_SalaryFlg number(1) NOT NULL,
	-- 指導員振分日数
	I_SalaryDays number(4,0) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode)
);


-- 工事施工予算データ明細
CREATE TABLE ConstructionBudgetDetail
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- グループ番号
	GroupCount number(2,0) NOT NULL,
	-- 行番号
	LineCount number(3,0) NOT NULL,
	-- 構成キー
	ComponentCode number(5,0) NOT NULL,
	-- 工種キー
	ItemCode number(5,0) NOT NULL,
	-- 項目名称
	FirstString nvarchar2(120),
	-- 工事内容
	SecondString nvarchar2(120),
	-- 協力会社コードタイプ
	CompanyType number(1) NOT NULL,
	-- 協力会社コード
	CompanyCode number(8,0) NOT NULL,
	-- 協力会社名称
	CompanyName nvarchar2(120),
	-- 積算時見積金額
	EstimatePrice number(12,2) NOT NULL,
	-- 積算時交渉金額
	NegotiationPrice number(12,2) NOT NULL,
	-- 発注希望金額
	OrderDesiredAmount number(12,2) NOT NULL,
	-- 実行金額
	ExecutionAmount number(12,2) NOT NULL,
	-- 金額構成率
	AmountConfigRate number(5,2) NOT NULL,
	-- 協力業者交渉フラグ
	NegotiateFlg number(1) NOT NULL,
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode, GroupCount, LineCount)
);


-- 工事詳細台帳データ
CREATE TABLE ConstructionLedger
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- 事業期
	ConstructionPeriod number(4,0) NOT NULL,
	-- 作成者コード
	CreatorCode number(8,0),
	-- 作成者名
	CreatorName nvarchar2(60),
	-- 作成日
	CreateDate date NOT NULL,
	-- 工期（単位・月）
	ConstructionTimes number(5,2) NOT NULL,
	-- 契約工期開始
	ConstructionStart date NOT NULL,
	-- 契約工期完了
	ConstructionEnd date NOT NULL,
	-- 税抜受注決定金額
	OrdersDecisionPrice number(14,2) NOT NULL,
	-- 会社経費合計
	CompanyExpenses number(10,2) NOT NULL,
	-- 部署経費合計
	DepartmentExpenses number(10,2) NOT NULL,
	-- 営業経費合計
	SalesExpenses number(10,2) NOT NULL,
	-- 総支払額
	TotalPayment number(10,2) NOT NULL,
	-- 粗利
	GrossProfit number(10,2) NOT NULL,
	-- 給与
	Allowance number(10,2) NOT NULL,
	-- 純利益
	NetProfit number(10,2) NOT NULL,
	-- 入力完了フラグ
	ComplateFlg number(1) NOT NULL,
	-- 受注金額積算フラグ
	IntegrationFlg number(1) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode)
);


-- 工事詳細台帳明細データ
CREATE TABLE ConstructionLedgerDetail
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- グループ番号
	GroupCount number(2,0) NOT NULL,
	-- 行番号
	LineCount number(3,0) NOT NULL,
	-- 構成キー
	ComponentCode number(5,0) NOT NULL,
	-- 工種キー
	ItemCode number(5,0) NOT NULL,
	-- 項目名称
	FirstString nvarchar2(120),
	-- 工事内容
	SecondString nvarchar2(120),
	-- 協力会社コードタイプ
	CompanyType number(1) NOT NULL,
	-- 協力会社コード
	CompanyCode number(8,0) NOT NULL,
	-- 協力会社名称
	CompanyName nvarchar2(120),
	-- 予算（見積）金額
	EstimatePrice number(12,2) NOT NULL,
	-- 実行金額
	ExecutionAmount number(12,2) NOT NULL,
	-- 金額構成率
	AmountConfigRate number(5,2) NOT NULL,
	-- 支払補填額
	PaymentBurden number(12,2) NOT NULL,
	-- 固定データフラグ
	FixDataFlg number(1) NOT NULL,
	-- 独立データフラグ
	IndependentFlg number(1) NOT NULL,
	-- 給与振分区分
	SalaryFlg number(1) NOT NULL,
	-- 給与振分日数
	SalaryDays number(4,0) NOT NULL,
	-- 担当中フラグ
	OperatingFlg number(1) NOT NULL,
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode, GroupCount, LineCount)
);


-- 工事詳細台帳実行データ
CREATE TABLE ConstructionLedgerExcute
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- グループ番号
	GroupCount number(2,0) NOT NULL,
	-- 行番号
	LineCount number(3,0) NOT NULL,
	-- 列番号
	ColumnCount number(3,0) NOT NULL,
	-- 支払金額
	PaymentAmount number(12,2) NOT NULL,
	-- 対象年月
	TargetMonth date NOT NULL,
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode, GroupCount, LineCount, ColumnCount)
);


-- 工事増減情報
CREATE TABLE ConstructionLink
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- 子工事番号
	FluctuationCode number(10,0) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode, FluctuationCode)
);


-- 案件進捗日付データ
CREATE TABLE ConstructionProgressDate
(
	-- 工事番号
	ConstructionCode number(10,0) NOT NULL,
	-- 設定工事状態
	ConstructionStatusFlg number(2,0) NOT NULL,
	-- 変更前状態
	PreviousStatusFlg number(2,0),
	-- 設定日付
	ChangeDate date NOT NULL,
	-- 設定担当者
	ChangePersonCode number(8,0) NOT NULL,
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode, ConstructionStatusFlg)
);


-- 担当者毎経費データ
CREATE TABLE CostDataOfPerson
(
	-- 担当者コード
	PersonCode number(8,0) NOT NULL,
	-- 対象日付
	ActionDate date NOT NULL,
	-- データ区分
	DataType number(1) NOT NULL,
	-- データ追加番号
	DataAddCount number(5,0) NOT NULL,
	-- 対象年月
	TargetMonth varchar2(7) NOT NULL,
	-- 工事番号
	ConstructionCode number(10,0),
	-- 支払先コード
	SuppliersCode number(5,0) NOT NULL,
	-- 支払先名称
	SuppliersName nvarchar2(120),
	-- 支払内容
	PaymentContent nvarchar2(60),
	-- 支払方法フラグ
	PaymentType number(1) NOT NULL,
	-- 金額
	EntryPrice number(12,2) NOT NULL,
	-- 引込済みフラグ
	ComplateFlg number(1) NOT NULL,
	-- 承認フラグ
	ApprovalFlg number(1) NOT NULL,
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (PersonCode, ActionDate, DataType, DataAddCount)
);


-- 日報データ
CREATE TABLE DailyDataConstruction
(
	-- 作成者コード
	PersonCode number(8,0) NOT NULL,
	-- 日報作成日
	DailyDataDate date NOT NULL,
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- 天気
	Weather nvarchar2(60),
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (PersonCode, DailyDataDate, ConstructionCode)
);


-- 日報データ (明細)
CREATE TABLE DailyDataDetail
(
	-- 作成者コード
	PersonCode number(8,0) NOT NULL,
	-- 日報作成日
	DailyDataDate date NOT NULL,
	-- 工事番号
	ConstructionCode number(10,0) NOT NULL,
	-- 明細行番号
	SeqNo number(3,0) NOT NULL,
	-- 職種キー
	JobCategoryCode number(5,0) NOT NULL,
	-- 協力会社コード
	CompanyCode number(8,0) NOT NULL,
	-- 当日人員数
	TodayHeadCount number(4,1) NOT NULL,
	-- 累計人員数
	TotalHeadCount number(5,1) NOT NULL,
	-- 当日作業内容
	TodayWork nvarchar2(100),
	-- 翌日作業内容
	NextdayWork nvarchar2(100),
	-- 翌日人員数
	NextdayHeadCount number(4,1) NOT NULL,
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (PersonCode, DailyDataDate, ConstructionCode, SeqNo)
);


-- 日報データ (現場巡回)
CREATE TABLE DailyDataField
(
	-- 作成者コード
	PersonCode number(8,0) NOT NULL,
	-- 日報作成日
	DailyDataDate date NOT NULL,
	-- 工事番号
	ConstructionCode number(10,0) NOT NULL,
	-- 明細行番号
	SeqNo number(3,0) NOT NULL,
	-- 巡回時間
	PatrolTime date NOT NULL,
	-- 内容
	ContentsText nvarchar2(200),
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (PersonCode, DailyDataDate, ConstructionCode, SeqNo)
);


-- 日報データ (資材)
CREATE TABLE DailyDataMaterials
(
	-- 作成者コード
	PersonCode number(8,0) NOT NULL,
	-- 日報作成日
	DailyDataDate date NOT NULL,
	-- 工事番号
	ConstructionCode number(10,0) NOT NULL,
	-- 明細行番号
	SeqNo number(3,0) NOT NULL,
	-- 資材名
	Materials nvarchar2(100),
	-- 数量
	Quantity nvarchar2(100),
	-- 制作会社
	Production nvarchar2(100),
	-- 納入業者
	Delivery nvarchar2(100),
	-- 品質管理事項
	QualityControl nvarchar2(100),
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (PersonCode, DailyDataDate, ConstructionCode, SeqNo)
);


-- 日報データ (協力業者指示)
CREATE TABLE DailyDataSubcontractors
(
	-- 作成者コード
	PersonCode number(8,0) NOT NULL,
	-- 日報作成日
	DailyDataDate date NOT NULL,
	-- 工事番号
	ConstructionCode number(10,0) NOT NULL,
	-- 明細行番号
	SeqNo number(3,0) NOT NULL,
	-- 出席者
	Attendee nvarchar2(100),
	-- 内容
	ContentsText nvarchar2(200),
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (PersonCode, DailyDataDate, ConstructionCode, SeqNo)
);


-- 日報データ (車両)
CREATE TABLE DailyDataVehicles
(
	-- 作成者コード
	PersonCode number(8,0) NOT NULL,
	-- 日報作成日
	DailyDataDate date NOT NULL,
	-- 工事番号
	ConstructionCode number(10,0) NOT NULL,
	-- 明細行番号
	SeqNo number(3,0) NOT NULL,
	-- 機種
	Model nvarchar2(100),
	-- 性能
	Performance nvarchar2(100),
	-- 所有会社
	Owner nvarchar2(100),
	-- 当日運転者
	Driver nvarchar2(100),
	-- 作業時間開始
	StartWorkingTime date NOT NULL,
	-- 作業時間終了
	EndWorkingTime date NOT NULL,
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (PersonCode, DailyDataDate, ConstructionCode, SeqNo)
);


-- 積算予算書データ
CREATE TABLE EstimateBudget
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- 工期
	ConstructionTime number(4,1) NOT NULL,
	-- 積算者
	IntegratedCode number(8,0) NOT NULL,
	-- データ引込日
	DataCreateDate date NOT NULL,
	-- 予定価格
	RetValue1 number(12,2) NOT NULL,
	-- 直接工事費
	RetValue2 number(12,2) NOT NULL,
	-- 積み上げ共通仮設費
	RetValue3 number(12,2) NOT NULL,
	-- 積み上げ現場管理費
	RetValue4 number(12,2) NOT NULL,
	-- 一般管理費率
	RetPercent number(5,2) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date,
	PRIMARY KEY (ConstructionCode)
);


-- 積算予算内訳データ明細
CREATE TABLE EstimateBudgetDetail
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- グループ番号
	GroupCount number(2,0) NOT NULL,
	-- 行番号
	LineCount number(3,0) NOT NULL,
	-- 構成キー
	ComponentCode number(5,0) NOT NULL,
	-- 工種キー
	ItemCode number(5,0),
	-- 協力会社コード
	CompanyCode number(8,0) NOT NULL,
	-- 大項目名称
	FirstString nvarchar2(120),
	-- 工種名称・協力会社名
	SecondString nvarchar2(120),
	-- 内容
	Content nvarchar2(120),
	-- 見積時金額
	EstimatePrice number(12,2) NOT NULL,
	-- 交渉時金額
	NegotiationPrice number(12,2) NOT NULL,
	-- 注意事項
	Notes nvarchar2(120),
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode, GroupCount, LineCount)
);


-- 積算見積データ
CREATE TABLE EstimateData
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- 行番号
	LineCount number(3,0) NOT NULL,
	-- 構成キー
	ComponentCode number(3,0) NOT NULL,
	-- 固定項目キー
	FixedItemCode varchar2(1),
	-- 作業名称
	ItemName nvarchar2(120),
	-- 作業／品質・形状・寸法
	SpecName nvarchar2(120),
	-- 金額
	PriceValue number(14,2) NOT NULL,
	-- 備考
	note nvarchar2(60),
	-- 自社経費フラグ
	MyExpensesFlg number(1) NOT NULL,
	-- 入力フラグ
	InputFlg number(1) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode, LineCount)
);


-- 積算見積ページデータ
CREATE TABLE EstimateDataBody
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- ページ番号
	PageCount number(4,0) NOT NULL,
	-- ページ区分
	Category number(1) NOT NULL,
	-- 所属構成キー
	UnionComponentCode number(5,0) NOT NULL,
	-- 構成キー
	ComponentCode number(5,0) NOT NULL,
	-- 工種キー
	ItemCode number(5,0) NOT NULL,
	-- 選択構成キー
	SelectComponent number(5,0) NOT NULL,
	-- ページ表示名
	PageTitle nvarchar2(120) NOT NULL,
	-- 明細行番号
	DetailLineCount number(3,0) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode, PageCount)
);


-- 積算見積データ明細
CREATE TABLE EstimateDataDetail
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- ページ番号
	PageCount number(4,0) NOT NULL,
	-- 行番号
	LineCount number(3,0) NOT NULL,
	-- データ種別
	DataType number(1) NOT NULL,
	-- 構成キー
	ComponentCode number(5,0) NOT NULL,
	-- 工種キー
	ItemCode number(5,0) NOT NULL,
	-- 作業キー
	SpecCode number(5,0) NOT NULL,
	-- 作業名称
	ItemName nvarchar2(120),
	-- 作業／品質・形状・寸法
	SpecName nvarchar2(120),
	-- 数量
	Unitcount number(8,2) NOT NULL,
	-- 単位名称
	UnitName nvarchar2(30),
	-- 単価
	UnitPrice number(9,2) NOT NULL,
	-- 金額
	LineTotal number(12,2) NOT NULL,
	-- 備考
	note nvarchar2(60),
	-- 協力会社コード
	CompanyCode number(8,0) NOT NULL,
	-- 自社経費フラグ
	MyExpensesFlg number(1) NOT NULL,
	-- 入力フラグ
	InputFlg number(1),
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode, PageCount, LineCount)
);


-- 入力時検索履歴
CREATE TABLE InputSearchLogData
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- 使用機能番号
	UsedProcessNo number(3,0) NOT NULL,
	-- 表示順
	DisplayOrder number(5,0) NOT NULL,
	-- データ種別
	DataType number(1) NOT NULL,
	-- 入力コード
	InputCode number(10,0),
	PRIMARY KEY (ConstructionCode, UsedProcessNo, DisplayOrder)
);


-- 掲示板メッセージ
CREATE TABLE MessageBoardData
(
	-- レコード番号
	RecordNumber number(6,0) NOT NULL,
	-- レコード枝番
	BranchNumber number(3,0) NOT NULL,
	-- 書込み者コード
	FromCode number(8,0) NOT NULL,
	-- 書込み者
	FromName nvarchar2(60) NOT NULL,
	-- 伝言タイトル
	MessageTitile nvarchar2(100),
	-- 伝言内容
	MessageContent nvarchar2(1333) NOT NULL,
	-- リンク動作タイプ
	LinkType number(2,0) NOT NULL,
	-- リンク文字列
	LinkMessage nvarchar2(200),
	-- リンクキー
	LinkCode varchar2(30),
	-- 書込み日時
	WritingDate date NOT NULL,
	-- 書込み担当者コード
	PersonCode number(8,0) NOT NULL,
	-- 管理者対象フラグ
	ShareFlag number(2,0) NOT NULL,
	-- 文字色
	MessageColor varchar2(8),
	-- バックカラー
	BackColor varchar2(8),
	-- メッセージフラグ
	MessageFlag number(1) NOT NULL,
	-- 登録日付
	EntryDate date,
	-- 更新日付
	UpdateDate date,
	PRIMARY KEY (RecordNumber, BranchNumber)
);


-- 掲示板対象者テーブル
CREATE TABLE MessageBoardTerget
(
	-- レコード番号
	RecordNumber number(6,0) NOT NULL,
	-- レコード枝番
	BranchNumber number(3,0) NOT NULL,
	-- 順番
	SeqNum number(3,0) NOT NULL,
	-- 対象者コード
	ToCode number(8,0) NOT NULL,
	-- 対象者
	ToName nvarchar2(60) NOT NULL,
	-- 登録日付
	EntryDate date,
	-- 更新日付
	UpdateDate date,
	PRIMARY KEY (RecordNumber, BranchNumber, SeqNum)
);


-- 掲示板メッセージ閲覧履歴
CREATE TABLE MessageBrowsingHistory
(
	-- レコード番号
	RecordNumber number(6,0) NOT NULL,
	-- レコード枝番
	BranchNumber number(3,0) NOT NULL,
	-- 順番
	SeqNum number(3,0) NOT NULL,
	-- 閲覧者コード
	BrowsingCode number(8,0) NOT NULL,
	-- 閲覧日付
	BrowsingDate date NOT NULL,
	-- 登録日付
	EntryDate date,
	-- 更新日付
	UpdateDate date,
	PRIMARY KEY (RecordNumber, BranchNumber, SeqNum)
);


-- 受注金額データ
CREATE TABLE OrdersPriceData
(
	-- 工事番号
	ConstructionCode number(10,0) NOT NULL,
	-- 変更番号
	ChangeNo number(3,0) NOT NULL,
	-- 変更日
	ChangeDate date NOT NULL,
	-- 変更者コード
	ChangePersonCode number(8,0) NOT NULL,
	-- 変更者名
	ChangePersonName nvarchar2(60),
	-- 変更前税抜受注金額
	BeforeValue number(14,2) NOT NULL,
	-- 変更前税込受注金額
	BeforeValueInTax number(14,2) NOT NULL,
	-- 変更後税抜受注金額
	AfterValue number(14,2) NOT NULL,
	-- 変更後税込受注金額
	AfterValueInTax number(14,2) NOT NULL,
	-- 変更理由
	ChangeComment nvarchar2(200),
	-- 登録年月日
	EntryDate date,
	-- 更新年月日
	UpdateDate date,
	PRIMARY KEY (ConstructionCode, ChangeNo)
);


-- 指示事項データ
CREATE TABLE PointingOutComment
(
	-- 工事コード
	ConstructionCode number(10,0) NOT NULL,
	-- 処理番号（画面番号）
	ProcessNo number(3,0) NOT NULL,
	-- 順序
	SeqNo number(3,0) NOT NULL,
	-- ページ番号
	PageCount number(4,0) NOT NULL,
	-- 記入者コード
	PersonCode number(8,0) NOT NULL,
	-- 描画色
	DrowColor varchar2(8),
	-- メッセージ
	CommentMessage nvarchar2(1000),
	-- 指摘項目位置Ｘ
	StartPointX number(4,0) NOT NULL,
	-- 指摘項目位置Ｙ
	StartPointY number(4,0) NOT NULL,
	-- 初期位置Ｘ
	CurrentPointX number(4,0) NOT NULL,
	-- 初期位置Ｙ
	CurrentPointY number(4,0) NOT NULL,
	-- 表示サイズWidth
	CurrentWidth number(4,0) NOT NULL,
	-- 表示サイズHeigth
	CurrentHeight number(4,0) NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode, ProcessNo, SeqNo)
);


-- 発注者打ち合わせ議事録データ
CREATE TABLE ProceedingsData
(
	-- 作成者コード
	PersonCode number(8,0) NOT NULL,
	-- 議事録作成日
	ProceedingsDataDate date NOT NULL,
	-- 工事番号
	ConstructionCode number(10,0) NOT NULL,
	-- 会議時間開始
	StartMeetingTime date NOT NULL,
	-- 会議時間終了
	EndMeetingTime date NOT NULL,
	-- 打合せ場所１
	MeetingPalce1 nvarchar2(100),
	-- 打合せ場所２
	MeetingPalce2 nvarchar2(100),
	-- 打合せ場所３
	MeetingPalce3 nvarchar2(100),
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (PersonCode, ProceedingsDataDate, ConstructionCode)
);


-- 発注者打ち合わせ議事録データ（出席者）
CREATE TABLE ProceedingsDataAttendee
(
	-- 作成者コード
	PersonCode number(8,0) NOT NULL,
	-- 議事録作成日
	ProceedingsDataDate date NOT NULL,
	-- 工事番号
	ConstructionCode number(10,0) NOT NULL,
	-- データ行番号
	SeqNo number(3,0) NOT NULL,
	-- 出席者所属
	Department nvarchar2(100),
	-- 出席者氏名
	AttendeeName nvarchar2(100),
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (PersonCode, ProceedingsDataDate, ConstructionCode, SeqNo)
);


-- 発注者打ち合わせ議事録データ（明細）
CREATE TABLE ProceedingsDataDetail
(
	-- 作成者コード
	PersonCode number(8,0) NOT NULL,
	-- 議事録作成日
	ProceedingsDataDate date NOT NULL,
	-- 工事番号
	ConstructionCode number(10,0) NOT NULL,
	-- データ行番号
	SeqNo number(3,0) NOT NULL,
	-- 議題番号
	TitileNo number(3,0),
	-- 議題
	Titile nvarchar2(100),
	-- 内容
	ContentsText nvarchar2(200),
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (PersonCode, ProceedingsDataDate, ConstructionCode, SeqNo)
);


-- 承認データ
CREATE TABLE ProcessApproval
(
	-- 工事番号
	ConstructionCode number(10,0) NOT NULL,
	-- 承認機能番号
	ApprovalCode number(3,0) NOT NULL,
	-- 枝番
	SeqNo number(2,0) NOT NULL,
	-- 申請・承認者コード
	PersonCode number(8,0) NOT NULL,
	-- 申請・承認日付
	PetitionApprovalDate date NOT NULL,
	-- 承認希望日
	ApprovalLimitDates date NOT NULL,
	-- 承認状態
	ApprovalStatus number(1) NOT NULL,
	-- コメント
	InputComment nvarchar2(300),
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode, ApprovalCode, SeqNo)
);


-- 注文書データ
CREATE TABLE PurchaseOrder
(
	-- 工事番号
	ConstructionCode number(10,0) NOT NULL,
	-- 注文書枝番
	SeqNo number(3,0) NOT NULL,
	-- 協力会社コード
	CompanyCode number(8,0) NOT NULL,
	-- 作成日付
	CreateDate date,
	-- 発注金額
	OrderPrice number(12,2) NOT NULL,
	-- 最終行表示日付
	LastRowStringDate date NOT NULL,
	-- 簡易・本式フラグ
	OrderSheetType number(1) NOT NULL,
	-- 支払い条件
	PaymentTerms number(1) NOT NULL,
	-- 現金割合（％）
	CashRatio number(4,1) NOT NULL,
	-- 手形期間
	BillPeriod number(4,0) NOT NULL,
	-- 前金払
	PrePayments number(1) NOT NULL,
	-- 前金払日数
	PrePaymentsDays number(3,0) NOT NULL,
	-- 前金払金額
	PrePaymentsPrice number(12,2) NOT NULL,
	-- 部分払
	PartialPayment number(1) NOT NULL,
	-- 部分払締切月
	PartialPaymentMounth number(2,0) NOT NULL,
	-- 部分払締切日
	PartialPaymentDay1 number(2,0) NOT NULL,
	-- 部分払支払日
	PartialPaymentDay2 number(2,0) NOT NULL,
	-- 部分払金額
	PartialPaymentPrice number(12,2) NOT NULL,
	-- 引渡し時の支払
	CompletionPayment number(1) NOT NULL,
	-- 引渡し時の支払日数
	CompletionPaymentDays number(3,0) NOT NULL,
	-- 引渡し時の支払金額
	CompletionPaymentPrice number(12,2) NOT NULL,
	-- 主任技術者コード
	LeadEngineerCode number(8,0),
	-- LeadEngineerName
	LeadEngineerName nvarchar2(60),
	-- 安全管理者コード
	SafetyOfficerCode number(8,0),
	-- 安全管理者名
	SafetyOfficerName nvarchar2(60),
	-- 作業員数
	WorkersCount number(3,0),
	-- 印刷年月日
	PrintoutDate date NOT NULL,
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode, SeqNo)
);


-- 注文書明細データ
CREATE TABLE PurchaseOrderDetail
(
	-- 工事番号
	ConstructionCode number(10,0) NOT NULL,
	-- 注文書枝番
	SeqNo number(3,0) NOT NULL,
	-- グループ番号
	GroupCount number(1) NOT NULL,
	-- 行番号
	LineCount number(3,0) NOT NULL,
	-- 構成キー
	ComponentCode number(5,0) NOT NULL,
	-- 工種キー
	ItemCode number(5,0) NOT NULL,
	-- 工種・品名
	FirstString nvarchar2(120),
	-- 内容内訳
	SecondString nvarchar2(120),
	-- 数量
	UnitCount number(8,2) NOT NULL,
	-- 単位
	UnitName nvarchar2(30),
	-- 単価
	UnitPrice number(10,2) NOT NULL,
	-- 金額
	OrdersLinePrice number(12,2),
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (ConstructionCode, SeqNo, GroupCount, LineCount)
);


-- 売上グラフデータ
CREATE TABLE SalesGraphData
(
	-- グラフデータコード
	GraphDataCode number(8,0) NOT NULL,
	-- 事業期
	ConstructionPeriod number(4,0) NOT NULL,
	-- 売上年月
	SalesDataDays date NOT NULL,
	-- 表示順
	DisplayOrder number(8,0) NOT NULL,
	-- データ表示名称
	DataName nvarchar2(100) NOT NULL,
	-- 売上データ
	SalesAmount number(10,0) NOT NULL,
	-- 販管・部署経費
	AdministrativeExpense number(10,0) NOT NULL,
	-- 粗利益
	GrossProfit number(10,0) NOT NULL,
	-- 純利益(損益)
	NetIncome number(10,0) NOT NULL,
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (GraphDataCode, ConstructionPeriod, SalesDataDays)
);


-- システム起動確認データ
CREATE TABLE SystemExecute
(
	-- キー項目
	PrimaryCode number(3,0) NOT NULL,
	-- 起動日付
	TargetDate date NOT NULL,
	-- 登録日付
	EntryDate date NOT NULL,
	-- 更新日付
	UpdateDate date NOT NULL,
	PRIMARY KEY (PrimaryCode)
);


-- 車両予約データ
CREATE TABLE VehicleScheduleData
(
	-- 対象日
	TargetDate date NOT NULL,
	-- 車両コード
	VehicleCode number(5,0) NOT NULL,
	-- 午前・午後
	MorningAfternoon number(1) NOT NULL,
	-- 担当者コード
	PersonCode number(8,0) NOT NULL,
	-- 該当年
	TargetYear number(4,0) NOT NULL,
	-- 該当月
	TargetMonth number(2,0) NOT NULL,
	-- 該当日
	TargetDay number(2,0) NOT NULL,
	-- 登録年月日
	EntryDate date NOT NULL,
	-- 更新年月日
	UpdateDate date NOT NULL,
	PRIMARY KEY (TargetDate, VehicleCode, MorningAfternoon)
);



/* Create Indexes */

CREATE INDEX ActionScheduleData_Index1 ON ActionScheduleData (TargetYear);
CREATE INDEX ActionScheduleData_Index2 ON ActionScheduleData (TargetMonth);
CREATE INDEX ActionScheduleData_Index3 ON ActionScheduleData (TargetDay);
CREATE INDEX ConstructionBaseInfo_Index1 ON ConstructionBaseInfo (ConstructionStatusFlg);
CREATE INDEX ConstructionBaseInfo_Index2 ON ConstructionBaseInfo (EstimateType);
CREATE INDEX ConstructionBaseInfo_Index3 ON ConstructionBaseInfo (SalesPersonCode);
CREATE INDEX ConstructionBaseInfo_Index4 ON ConstructionBaseInfo (ConstructionPersonCode);
CREATE INDEX ConstructionBaseInfo_Index5 ON ConstructionBaseInfo (ConstructionInstructor);
CREATE INDEX BaseInfoDetail_Idx1 ON ConstructionBaseInfoDetail (ConstructionCode);
CREATE INDEX BaseInfoDetail_Idx2 ON ConstructionBaseInfoDetail (DetailNo);
CREATE INDEX LedgerExcute_Index1 ON ConstructionLedgerExcute (ConstructionCode, TargetMonth, GroupCount, LineCount);
CREATE INDEX CostDataOfPerson_Index1 ON CostDataOfPerson (TargetMonth);
CREATE INDEX CostDataOfPerson_Index2 ON CostDataOfPerson (ConstructionCode);
CREATE INDEX EstimateData_Index1 ON EstimateData (ConstructionCode, FixedItemCode);
CREATE INDEX EstimateDataBody_Index1 ON EstimateDataBody (ConstructionCode, ComponentCode, ItemCode);
CREATE INDEX EstimateDataDetail_Index1 ON EstimateDataDetail (ConstructionCode, PageCount);
CREATE INDEX InputSearchLogData_Index1 ON InputSearchLogData (ConstructionCode, UsedProcessNo, InputCode);
CREATE INDEX MessageBoardData_Index1 ON MessageBoardData (WritingDate);
CREATE INDEX MessageBoardData_Index2 ON MessageBoardData (MessageFlag);
CREATE INDEX MessageBoardTerget_Index1 ON MessageBoardTerget (RecordNumber, BranchNumber);
CREATE INDEX SalesGraphData_Idx1 ON SalesGraphData (DisplayOrder);
CREATE INDEX SalesGraphData_idx2 ON SalesGraphData (ConstructionPeriod);
CREATE INDEX VehicleScheduleData_Index1 ON VehicleScheduleData (TargetYear);
CREATE INDEX VehicleScheduleData_Index2 ON VehicleScheduleData (TargetMonth);
CREATE INDEX VehicleScheduleData_Index3 ON VehicleScheduleData (TargetDay);



